@@ -91,10 +91,20 @@ func Failed(msg string, args ...interface{}) {
 
 // Navigate navigates to jira issue.
 func Navigate(server, path string) error {
-	url := fmt.Sprintf("%s/browse/%s", server, path)
+	url := GenerateServerBrowseURL(server, path)
 	return browser.Browse(url)
 }
 
+// GenerateServerBrowseURL will return the `browse` URL for a given key.
+// The server section can be overridden via `browse_server` in config.
+// This is useful if your API endpoint is separate from the web client endpoint.
+func GenerateServerBrowseURL(server, key string) string {
+	if viper.GetString("browse_server") != "" {
+		server = viper.GetString("browse_server")
+	}
+	return fmt.Sprintf("%s/browse/%s", server, key)
+}
+
 // FormatDateTimeHuman formats date time in human readable format.
 func FormatDateTimeHuman(dt, format string) string {
 	t, err := time.Parse(format, dt)
